@@ -17,13 +17,6 @@ import (
 	"github.com/spf13/cobra"
 	"k8s.io/klog/v2"
 
-	configclient "github.com/openshift/client-go/config/clientset/versioned"
-	imagev1client "github.com/openshift/client-go/image/clientset/versioned/typed/image/v1"
-	"github.com/openshift/library-go/pkg/image/imageutil"
-	imagereference "github.com/openshift/library-go/pkg/image/reference"
-	"github.com/openshift/library-go/pkg/operator/resource/retry"
-	"github.com/openshift/oc/pkg/cli/admin/inspect"
-	"github.com/openshift/oc/pkg/cli/rsync"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	kerrors "k8s.io/apimachinery/pkg/api/errors"
@@ -39,6 +32,14 @@ import (
 	"k8s.io/kubectl/pkg/polymorphichelpers"
 	"k8s.io/kubectl/pkg/scheme"
 	"k8s.io/kubectl/pkg/util/templates"
+
+	imagev1client "github.com/openshift/client-go/image/clientset/versioned/typed/image/v1"
+	"github.com/openshift/library-go/pkg/image/imageutil"
+	imagereference "github.com/openshift/library-go/pkg/image/reference"
+	"github.com/openshift/library-go/pkg/operator/resource/retry"
+
+	"github.com/openshift/oc/pkg/cli/admin/inspect"
+	"github.com/openshift/oc/pkg/cli/rsync"
 )
 
 var (
@@ -103,7 +104,6 @@ func NewMustGatherOptions(streams genericclioptions.IOStreams) *MustGatherOption
 		SourceDir: "/must-gather/",
 		IOStreams: streams,
 		LogOut:    newPrefixWriter(streams.Out, "[must-gather      ] OUT"),
-		RawOut:    streams.Out,
 		Timeout:   10 * time.Minute,
 	}
 }
@@ -117,9 +117,6 @@ func (o *MustGatherOptions) Complete(f kcmdutil.Factory, cmd *cobra.Command, arg
 	if o.Client, err = kubernetes.NewForConfig(o.Config); err != nil {
 		return err
 	}
-	if o.ConfigClient, err = configclient.NewForConfig(o.Config); err != nil {
-		return err
-	}
 	if o.ImageClient, err = imagev1client.NewForConfig(o.Config); err != nil {
 		return err
 	}
@@ -174,11 +171,11 @@ func (o *MustGatherOptions) completeImages() error {
 		var err error
 		if image, err = o.resolveImageStreamTag("openshift", "must-gather", "latest"); err != nil {
 			o.log("%v\n", err)
-			image = "quay.io/openshift/origin-must-gather:latest"
+			image = "registry.redhat.io/openshift4/ose-must-gather:latest"
 		}
 		o.Images = append(o.Images, image)
 	}
-	o.log("Using must-gather plugin-in image: %s", strings.Join(o.Images, ", "))
+	o.log("Using must-gather plug-in image: %s", strings.Join(o.Images, ", "))
 	return nil
 }
 
@@ -222,7 +219,6 @@ type MustGatherOptions struct {
 
 	Config           *rest.Config
 	Client           kubernetes.Interface
-	ConfigClient     configclient.Interface
 	ImageClient      imagev1client.ImageV1Interface
 	RESTClientGetter genericclioptions.RESTClientGetter
 
@@ -241,8 +237,6 @@ type MustGatherOptions struct {
 	PrinterCreated printers.ResourcePrinter
 	PrinterDeleted printers.ResourcePrinter
 	LogOut         io.Writer
-	// RawOut is used for printing information we're looking to have copy/pasted into bugs
-	RawOut io.Writer
 }
 
 func (o *MustGatherOptions) Validate() error {
@@ -256,21 +250,6 @@ func (o *MustGatherOptions) Validate() error {
 func (o *MustGatherOptions) Run() error {
 	var err error
 
-	runBackCollection := true
-	defer func() {
-		if !runBackCollection {
-			return
-		}
-		o.BackupGathering(context.TODO())
-	}()
-
-	// print at both the beginning and at the end.  This information is important enough to be in both spots.
-	o.PrintBasicClusterState(context.TODO())
-	defer func() {
-		fmt.Fprintf(o.RawOut, "\n\n")
-		o.PrintBasicClusterState(context.TODO())
-	}()
-
 	// create namespace ...
 	ns, err := o.Client.CoreV1().Namespaces().Create(context.TODO(), &corev1.Namespace{
 		ObjectMeta: metav1.ObjectMeta{
@@ -389,15 +368,6 @@ func (o *MustGatherOptions) Run() error {
 	for i := range errCh {
 		errs = append(errs, i)
 	}
-	if len(errs) == 0 {
-		// If we didn't have an error during collection, then we don't need to do our backup collection.
-		runBackCollection = false
-
-	} else if len(o.Command) > 0 {
-		// If we had errors, but the user specified a command, he probably just typoed the command.
-		// If the command was specified, don't run the backup collection.
-		runBackCollection = false
-	}
 
 	// now gather all the events into a single file and produce a unified file
 	if err := inspect.CreateEventFilterPage(o.DestDir); err != nil {
@@ -661,23 +631,3 @@ func (o *MustGatherOptions) newPod(node, image string) *corev1.Pod {
 
 	return ret
 }
-
-// BackupGathering is called if the full must-gather has an error.  This is useful for making sure we get *something*
-// no matter what has failed.  It should be focused on universal openshift failures.
-func (o *MustGatherOptions) BackupGathering(ctx context.Context) {
-	inspectOptions := inspect.NewInspectOptions(o.IOStreams)
-	inspectOptions.RESTConfig = rest.CopyConfig(o.Config)
-	inspectOptions.DestDir = o.DestDir
-	if err := inspectOptions.Complete([]string{"clusteroperators.v1.config.openshift.io"}); err != nil {
-		fmt.Fprintf(o.ErrOut, "error completing backup collection: %v", err)
-		return
-	}
-	if err := inspectOptions.Validate(); err != nil {
-		fmt.Fprintf(o.ErrOut, "error validating backup collection: %v", err)
-		return
-	}
-	if err := inspectOptions.Run(); err != nil {
-		fmt.Fprintf(o.ErrOut, "error running backup collection: %v", err)
-		return
-	}
-}
